var searchData=
[
  ['macgetcommonmenubar',['MacGetCommonMenuBar',['../classwx_menu_bar.html#ab64676b036f37ff43df842b0dfffa39e',1,'wxMenuBar']]],
  ['macnewfile',['MacNewFile',['../classwx_app.html#adfccb56471d139a0bb29e96c3c6d12fa',1,'wxApp']]],
  ['macopenfile',['MacOpenFile',['../classwx_app.html#a420a1cef557cfe2edaee6ffdaaa5f7fb',1,'wxApp']]],
  ['macopenfiles',['MacOpenFiles',['../classwx_app.html#a0cf8d83fc9e1a7b7f911f29f05127d24',1,'wxApp']]],
  ['macopenurl',['MacOpenURL',['../classwx_app.html#a2c0ab6480ef6113488a5847a79044ac7',1,'wxApp']]],
  ['macprintfile',['MacPrintFile',['../classwx_app.html#a1f6e5bc7e119f4394fddae1782acd047',1,'wxApp']]],
  ['macreopenapp',['MacReopenApp',['../classwx_app.html#a2054c2fadff9170b91e474eb02c83227',1,'wxApp']]],
  ['macsetcommonmenubar',['MacSetCommonMenuBar',['../classwx_menu_bar.html#a1fd28115be9437d0dd7b1f99049ec905',1,'wxMenuBar']]],
  ['magnify',['Magnify',['../classwx_mouse_event.html#a4ff3ee248bd6b2cb39f6d6e543a71e24',1,'wxMouseEvent']]],
  ['mainloop',['MainLoop',['../classwx_app_console.html#a14523f3e9ab468c19c697c65484b36db',1,'wxAppConsole']]],
  ['majorversion',['MajorVersion',['../classwx_g_l_context_attrs.html#a2855080de73bdd23cbbfbceddc35bbee',1,'wxGLContextAttrs']]],
  ['make',['Make',['../classwx_date_time_1_1_time_zone.html#a6bed142b6b0716f1100f8205e06db623',1,'wxDateTime::TimeZone::Make()'],['../classwx_dir.html#a97ee8e2dc2154b14bcd4b2f78cb5733d',1,'wxDir::Make()']]],
  ['makeabsolute',['MakeAbsolute',['../classwx_file_name.html#af947660cf109c3a39c4997f18a8670b6',1,'wxFileName']]],
  ['makebold',['MakeBold',['../classwx_font.html#a490c5c47ce9d42a9b430664c476e3940',1,'wxFont']]],
  ['makecapitalized',['MakeCapitalized',['../classwx_string.html#a7a8ec48b76dac441cd11db49f418d413',1,'wxString']]],
  ['makecellvisible',['MakeCellVisible',['../classwx_grid.html#a97bca062601229ebfc7069eb97ffab8a',1,'wxGrid::MakeCellVisible(int row, int col)'],['../classwx_grid.html#a8a8aa088c6a5093d5a7ca67be9178bcc',1,'wxGrid::MakeCellVisible(const wxGridCellCoords &amp;coords)']]],
  ['makecolumneditable',['MakeColumnEditable',['../classwx_property_grid.html#a5c67655306de7aa158518360be66b0c7',1,'wxPropertyGrid']]],
  ['makeconnection',['MakeConnection',['../classwx_d_d_e_client.html#a5d0f1d6d23eb7a55b7ff39300f5a9fbe',1,'wxDDEClient::MakeConnection()'],['../classwx_client.html#a6ca1cef89e834a724d34edf9872f545d',1,'wxClient::MakeConnection()'],['../classwx_t_c_p_client.html#a5575e6732a4710c238cd96034f723421',1,'wxTCPClient::MakeConnection()']]],
  ['makedisabled',['MakeDisabled',['../classwx_colour.html#afc71a8208268eb8fa682e43524478c69',1,'wxColour::MakeDisabled(unsigned char *r, unsigned char *g, unsigned char *b, unsigned char brightness=255)'],['../classwx_colour.html#afcaf1a9e713d058ab624cef834557bb6',1,'wxColour::MakeDisabled(unsigned char brightness=255)']]],
  ['makeeditable',['MakeEditable',['../classwx_web_kit_ctrl.html#a2fe1a40fc028849e87941b560e43ad45',1,'wxWebKitCtrl']]],
  ['makefromtimezone',['MakeFromTimezone',['../classwx_date_time.html#a83cff1eb8079f9eef5c386a5701d8803',1,'wxDateTime']]],
  ['makegrey',['MakeGrey',['../classwx_colour.html#a45e74c88fdab10e07164abe02c1b011a',1,'wxColour::MakeGrey(unsigned char *r, unsigned char *g, unsigned char *b)'],['../classwx_colour.html#a9020f882bba4f92bb68fcc7fd6d7cff4',1,'wxColour::MakeGrey(unsigned char *r, unsigned char *g, unsigned char *b, double weight_r, double weight_g, double weight_b)']]],
  ['makeimageblock',['MakeImageBlock',['../classwx_rich_text_image_block.html#a4a028d2960ed2a9c905b27c1a291941f',1,'wxRichTextImageBlock::MakeImageBlock(const wxString &amp;filename, wxBitmapType imageType, wxImage &amp;image, bool convertToJPEG=true)'],['../classwx_rich_text_image_block.html#a39362bb436b9c69b06c0abaec3e5cfaf',1,'wxRichTextImageBlock::MakeImageBlock(wxImage &amp;image, wxBitmapType imageType, int quality=80)']]],
  ['makeimageblockdefaultquality',['MakeImageBlockDefaultQuality',['../classwx_rich_text_image_block.html#a29db114a40982d633c01ab90f03adcb6',1,'wxRichTextImageBlock']]],
  ['makeitalic',['MakeItalic',['../classwx_font.html#a656641cb094eaa574be999ca791ced96',1,'wxFont']]],
  ['makekey',['MakeKey',['../classwx_hash_table.html#a4336375442bdc3e8e0987f23650da350',1,'wxHashTable::MakeKey()'],['../classwx_image_histogram.html#a08e2a0087ca6ca3a56c529e444c5ae8d',1,'wxImageHistogram::MakeKey()']]],
  ['makelarger',['MakeLarger',['../classwx_font.html#aae5977e23525729e23d3ac4dbc70c365',1,'wxFont']]],
  ['makelower',['MakeLower',['../classwx_string.html#a3b211c6f784d687ee9bb6033a4684071',1,'wxString']]],
  ['makemono',['MakeMono',['../classwx_colour.html#a0ba8c496e7553e34643e53e70de57760',1,'wxColour']]],
  ['makenewdocumentname',['MakeNewDocumentName',['../classwx_doc_manager.html#a10a40637ffd9c2405d38f4bc97ba3a6e',1,'wxDocManager']]],
  ['makenull',['MakeNull',['../classwx_any.html#ab229cda7063a3c3a82330b6dd7b3550c',1,'wxAny::MakeNull()'],['../classwx_variant.html#ae626ad693c64badb2cfc5e8fe7a7edd1',1,'wxVariant::MakeNull()']]],
  ['makeobject',['MakeObject',['../classwx_rich_text_action.html#ae83b07dc6b3208d9e74a15491cecf2fe',1,'wxRichTextAction']]],
  ['makerelativeto',['MakeRelativeTo',['../classwx_file_name.html#ab7ac6ac2f4f0d7dca3fd9c9764ec818d',1,'wxFileName']]],
  ['makesmaller',['MakeSmaller',['../classwx_font.html#a119d3c74838fe89bc4f36ebd698421a2',1,'wxFont']]],
  ['makestrikethrough',['MakeStrikethrough',['../classwx_font.html#a39b684e80dcc0e05e4aee6c3c1daa0a8',1,'wxFont']]],
  ['makestring',['MakeString',['../classwx_variant.html#ad6843bd4389d5140f40c39d0b12f35d9',1,'wxVariant']]],
  ['maketabvisible',['MakeTabVisible',['../classwx_aui_tab_container.html#ab530e4aebb04e570d20ebd3832ab3ae1',1,'wxAuiTabContainer']]],
  ['maketimezone',['MakeTimezone',['../classwx_date_time.html#ad6ce9eb1fb237eda8013695ebd531af1',1,'wxDateTime']]],
  ['makeunderlined',['MakeUnderlined',['../classwx_font.html#a6b44689f563aebc1f55e8fd09ba4315f',1,'wxFont']]],
  ['makeupper',['MakeUpper',['../classwx_string.html#af862e46d093e1e52fbc4f204e9aea34f',1,'wxString']]],
  ['makeutc',['MakeUTC',['../classwx_date_time.html#aa7e62cebf49c1c6b765e70ec19caedc0',1,'wxDateTime']]],
  ['makevalid',['MakeValid',['../classwx_text_attr_border.html#ac9948397daf971ec2405f0928c62fbb9',1,'wxTextAttrBorder']]],
  ['mapscreensizetodevice',['MapScreenSizeToDevice',['../classwx_printout.html#a3fa364935e551748a70a7126d22df728',1,'wxPrintout']]],
  ['mapscreensizetopage',['MapScreenSizeToPage',['../classwx_printout.html#acb6a81daabfcfcf601a877bdc69fa46b',1,'wxPrintout']]],
  ['mapscreensizetopagemargins',['MapScreenSizeToPageMargins',['../classwx_printout.html#aa38f61997d6764e51468fd76078b241e',1,'wxPrintout']]],
  ['mapscreensizetopaper',['MapScreenSizeToPaper',['../classwx_printout.html#a434261996b9cec78ee5cbc61bac9caf7',1,'wxPrintout']]],
  ['margingetstyle',['MarginGetStyle',['../classwx_styled_text_ctrl.html#a89ed079381f546ef0719f02918506734',1,'wxStyledTextCtrl']]],
  ['margingetstyleoffset',['MarginGetStyleOffset',['../classwx_styled_text_ctrl.html#a6e4f08253296b1614aba0d34304f2e7b',1,'wxStyledTextCtrl']]],
  ['margingetstyles',['MarginGetStyles',['../classwx_styled_text_ctrl.html#acae15a86c4716929b7d38439668496cf',1,'wxStyledTextCtrl']]],
  ['margingettext',['MarginGetText',['../classwx_styled_text_ctrl.html#a38844cc95c2c74cc3de5821e78757146',1,'wxStyledTextCtrl']]],
  ['marginsetstyle',['MarginSetStyle',['../classwx_styled_text_ctrl.html#ae552ef3d00be362facd155efdbb06644',1,'wxStyledTextCtrl']]],
  ['marginsetstyleoffset',['MarginSetStyleOffset',['../classwx_styled_text_ctrl.html#a07193d7b379e085991b840344293f4b1',1,'wxStyledTextCtrl']]],
  ['marginsetstyles',['MarginSetStyles',['../classwx_styled_text_ctrl.html#a9b5d745fe8da43d83fed85baa7bfe0f0',1,'wxStyledTextCtrl']]],
  ['marginsettext',['MarginSetText',['../classwx_styled_text_ctrl.html#ad66c7d820d12a5cc6f82aa72935fbbea',1,'wxStyledTextCtrl']]],
  ['margintextclearall',['MarginTextClearAll',['../classwx_styled_text_ctrl.html#ade9ece6d3f3a4373283c12b77f6469c4',1,'wxStyledTextCtrl']]],
  ['mark',['Mark',['../classwx_calendar_ctrl.html#a7273a1c06a5a838c0a2980dececdf4f0',1,'wxCalendarCtrl']]],
  ['markassaved',['MarkAsSaved',['../classwx_command_processor.html#a5ab022fc24cbc1ebd86a0c2edb4b4de8',1,'wxCommandProcessor']]],
  ['markdirty',['MarkDirty',['../classwx_rich_text_ctrl.html#a1ac127128831c1905a5506ed48a83570',1,'wxRichTextCtrl::MarkDirty()'],['../classwx_styled_text_ctrl.html#a1e2fd82c4b7d4c87fa0ad2e2d92abc95',1,'wxStyledTextCtrl::MarkDirty()'],['../classwx_text_ctrl.html#ab89671b5cd9e2da9a978f14e0f9931cf',1,'wxTextCtrl::MarkDirty()']]],
  ['markeradd',['MarkerAdd',['../classwx_styled_text_ctrl.html#a2bce811d7d23416b4aed7068f55f48a5',1,'wxStyledTextCtrl']]],
  ['markeraddset',['MarkerAddSet',['../classwx_styled_text_ctrl.html#ac1ebd9b3c385a00140f753d3b52d98cf',1,'wxStyledTextCtrl']]],
  ['markerdefine',['MarkerDefine',['../classwx_styled_text_ctrl.html#af4aff2744a8d3fc28f8f6f126e6da49b',1,'wxStyledTextCtrl']]],
  ['markerdefinebitmap',['MarkerDefineBitmap',['../classwx_styled_text_ctrl.html#adeefe5392b7394fb98ebf0291385c76a',1,'wxStyledTextCtrl']]],
  ['markerdefinergbaimage',['MarkerDefineRGBAImage',['../classwx_styled_text_ctrl.html#a7549a152211af4fba9ec09627bf64c2f',1,'wxStyledTextCtrl']]],
  ['markerdelete',['MarkerDelete',['../classwx_styled_text_ctrl.html#aea89da40e6dfdaa26a9a74a1067f651f',1,'wxStyledTextCtrl']]],
  ['markerdeleteall',['MarkerDeleteAll',['../classwx_styled_text_ctrl.html#a59e91381c363f396bd0c26ef9574515d',1,'wxStyledTextCtrl']]],
  ['markerdeletehandle',['MarkerDeleteHandle',['../classwx_styled_text_ctrl.html#a0db2a7ba33d022a973f82bd21a6c6e41',1,'wxStyledTextCtrl']]],
  ['markerenablehighlight',['MarkerEnableHighlight',['../classwx_styled_text_ctrl.html#aba8bda36ef191f934608aa4a4280ee44',1,'wxStyledTextCtrl']]],
  ['markerget',['MarkerGet',['../classwx_styled_text_ctrl.html#a681d408ab69cd6e63204b8359bb44605',1,'wxStyledTextCtrl']]],
  ['markerlinefromhandle',['MarkerLineFromHandle',['../classwx_styled_text_ctrl.html#a43af4651e826d2d92bc135fe8170c518',1,'wxStyledTextCtrl']]],
  ['markernext',['MarkerNext',['../classwx_styled_text_ctrl.html#ad2fed626190435a772aa5b00f725d2ef',1,'wxStyledTextCtrl']]],
  ['markerprevious',['MarkerPrevious',['../classwx_styled_text_ctrl.html#a5dba6328004c17faaecacc2647ac043d',1,'wxStyledTextCtrl']]],
  ['markersetalpha',['MarkerSetAlpha',['../classwx_styled_text_ctrl.html#ae3d48bdff0d995bfbf35ea29cff7b5bc',1,'wxStyledTextCtrl']]],
  ['markersetbackground',['MarkerSetBackground',['../classwx_styled_text_ctrl.html#ad11e02f4a07cdbd45c3627a0ce8fa5e8',1,'wxStyledTextCtrl']]],
  ['markersetbackgroundselected',['MarkerSetBackgroundSelected',['../classwx_styled_text_ctrl.html#a482ffb91166637376590f3f6a6c63b2d',1,'wxStyledTextCtrl']]],
  ['markersetforeground',['MarkerSetForeground',['../classwx_styled_text_ctrl.html#a7b038202798c153f2ba6c454dfa9f92b',1,'wxStyledTextCtrl']]],
  ['matches',['Matches',['../classwx_reg_ex.html#a4f63e65c83d19d7f4115e0cb46d797f2',1,'wxRegEx::Matches(const wxChar *text, int flags=0) const '],['../classwx_reg_ex.html#a761c31d59bc171d4c526e7d1da76ec9f',1,'wxRegEx::Matches(const wxChar *text, int flags, size_t len) const '],['../classwx_reg_ex.html#aac3f3acd35f8daf37ab2837473188e6a',1,'wxRegEx::Matches(const wxString &amp;text, int flags=0) const '],['../classwx_string.html#a0fef65e3bf7f77fa6858521f29a84e20',1,'wxString::Matches()'],['../structwx_video_mode.html#a5f9f9e2335cc8b87fadbb404fc2f47e0',1,'wxVideoMode::Matches()']]],
  ['max_5fsize',['max_size',['../classwx_list_3_01_t_01_4.html#aef1bb3d170c87215ff36443773a37017',1,'wxList&lt; T &gt;::max_size()'],['../classwx_string.html#a13471470cbc1443525bedef99e179baa',1,'wxString::max_size()']]],
  ['maximize',['Maximize',['../classwx_m_d_i_child_frame.html#a050f0818cb669338ad74b189b77e9b20',1,'wxMDIChildFrame::Maximize()'],['../classwx_top_level_window.html#addb1612e9f00ac82c2e19c2bac6ffc4f',1,'wxTopLevelWindow::Maximize()']]],
  ['maximizebutton',['MaximizeButton',['../classwx_aui_pane_info.html#a28842138907b56235c8f8ce3da77089b',1,'wxAuiPaneInfo']]],
  ['maxsize',['MaxSize',['../classwx_aui_pane_info.html#a9e2da447d00c6a7ce3a8440592a9b996',1,'wxAuiPaneInfo::MaxSize(const wxSize &amp;size)'],['../classwx_aui_pane_info.html#a68107e3967faae0260f49af227f55254',1,'wxAuiPaneInfo::MaxSize(int x, int y)']]],
  ['maxx',['MaxX',['../classwx_d_c.html#a8829696c6ebabed7053f8a9479fabeef',1,'wxDC']]],
  ['maxy',['MaxY',['../classwx_d_c.html#a90b1bc13bd01e442754e91935a8d0ef3',1,'wxDC']]],
  ['mb2wc',['MB2WC',['../classwx_m_b_conv.html#a79d63eff51836148157c986943835742',1,'wxMBConv']]],
  ['mb_5fstr',['mb_str',['../classwx_string.html#adcfd12e6d0765b1d74bccc3d63d02e98',1,'wxString']]],
  ['measurebullet',['MeasureBullet',['../classwx_rich_text_renderer.html#a9f0c3be99190db7ec7dbe6e5bf11b58e',1,'wxRichTextRenderer::MeasureBullet()'],['../classwx_rich_text_std_renderer.html#a329113733f77c5c20d42fe8cf831845f',1,'wxRichTextStdRenderer::MeasureBullet()']]],
  ['member',['Member',['../classwx_list_3_01_t_01_4.html#a710612f09a76d234d949724405338e1d',1,'wxList&lt; T &gt;::Member()'],['../classwx_variant.html#ac28c74227400cd94366d081eaf4fc3dc',1,'wxVariant::Member()']]],
  ['merge',['Merge',['../classwx_rich_text_object.html#ad70ee3cfab55a5e48fb604f915871843',1,'wxRichTextObject::Merge()'],['../classwx_rich_text_plain_text.html#a34521d526e4897ae4bce16a478a8a342',1,'wxRichTextPlainText::Merge()'],['../classwx_text_attr.html#a591d90d4a675dcbdcd57bbef5557669b',1,'wxTextAttr::Merge(const wxTextAttr &amp;overlay)'],['../classwx_text_attr.html#ad51cefa334bbfa1bdcff33c05bf0c6ef',1,'wxTextAttr::Merge(const wxTextAttr &amp;base, const wxTextAttr &amp;overlay)']]],
  ['mergefrom',['MergeFrom',['../classwx_p_g_cell.html#aea2453886dc54ec6ac6144acf4d95597',1,'wxPGCell']]],
  ['mergeproperties',['MergeProperties',['../classwx_rich_text_properties.html#a65fc66fcdd2d8f2687ee8af98304284a',1,'wxRichTextProperties']]],
  ['messageparameters',['MessageParameters',['../classwx_file_type_1_1_message_parameters.html#aacde350078c87df6853aa3949981a165',1,'wxFileType::MessageParameters::MessageParameters()'],['../classwx_file_type_1_1_message_parameters.html#a148911b186f3eab01ba3864a4383d826',1,'wxFileType::MessageParameters::MessageParameters(const wxString &amp;filename, const wxString &amp;mimetype=wxEmptyString)']]],
  ['metadown',['MetaDown',['../classwx_mouse_event.html#ac54b0063ff887f434fee23b5b1d4b518',1,'wxMouseEvent::MetaDown()'],['../classwx_grid_event.html#ad27099c2883b15e81863a432e7085186',1,'wxGridEvent::MetaDown()'],['../classwx_grid_size_event.html#a2d5feec68f9197cb89d011b0b5e5703e',1,'wxGridSizeEvent::MetaDown()'],['../classwx_grid_range_select_event.html#a8d872a1cee5110b0e4c900f656fcce4f',1,'wxGridRangeSelectEvent::MetaDown()'],['../classwx_keyboard_state.html#a8875366f7792d7fd5308cc240f5f0c5f',1,'wxKeyboardState::MetaDown()']]],
  ['mid',['Mid',['../classwx_string.html#a023d5f6b708eff5123f47498fcf151bc',1,'wxString']]],
  ['middledclick',['MiddleDClick',['../classwx_mouse_event.html#a7b72bd9b0aa9e735a14a91b8ff0464cb',1,'wxMouseEvent']]],
  ['middledown',['MiddleDown',['../classwx_mouse_event.html#aaf49416df9acaea3bb71470b753a1b18',1,'wxMouseEvent']]],
  ['middleisdown',['MiddleIsDown',['../classwx_mouse_state.html#ad6ddb394c20f1a826043dea8032e6845',1,'wxMouseState']]],
  ['middleup',['MiddleUp',['../classwx_mouse_event.html#ac54542740e9bac83c4446846782d7733',1,'wxMouseEvent']]],
  ['millisecond',['Millisecond',['../classwx_time_span.html#a5b979776a9120071f0602e21a5be733f',1,'wxTimeSpan']]],
  ['milliseconds',['Milliseconds',['../classwx_time_span.html#aab4dda04fc0654b91e0829e17fb9d59d',1,'wxTimeSpan']]],
  ['minacumrgba',['MinAcumRGBA',['../classwx_g_l_attributes.html#ad85c13eead96b8abaa5b50f2057f6316',1,'wxGLAttributes']]],
  ['minimizebutton',['MinimizeButton',['../classwx_aui_pane_info.html#a99aee8968a56af51780f78bcc4752cc8',1,'wxAuiPaneInfo']]],
  ['minorversion',['MinorVersion',['../classwx_g_l_context_attrs.html#a1acea1a1e0c8f7d54a0c46093bc8914c',1,'wxGLContextAttrs']]],
  ['minrgba',['MinRGBA',['../classwx_g_l_attributes.html#a9fa858e5227677156a67b9577c47ca7e',1,'wxGLAttributes']]],
  ['minsize',['MinSize',['../classwx_aui_pane_info.html#a67cf6e2c79120febdd32c6156eeddd54',1,'wxAuiPaneInfo::MinSize(const wxSize &amp;size)'],['../classwx_aui_pane_info.html#a1207db6a7a30a58ca5b720343f75db9d',1,'wxAuiPaneInfo::MinSize(int x, int y)']]],
  ['minute',['Minute',['../classwx_time_span.html#af2c88d43853d1168eee6f816b3aafcb3',1,'wxTimeSpan']]],
  ['minutes',['Minutes',['../classwx_time_span.html#ac1207a105513060a4ce39b5f6b4fe6d1',1,'wxTimeSpan']]],
  ['minx',['MinX',['../classwx_d_c.html#a603de4a911be9500e5eb5ffda87750bc',1,'wxDC']]],
  ['miny',['MinY',['../classwx_d_c.html#aecfe126a0ebb9818f1b3abf43675e744',1,'wxDC']]],
  ['mirror',['Mirror',['../classwx_affine_matrix2_d.html#a5bec8e0a74908b53c46dd67d8013837c',1,'wxAffineMatrix2D::Mirror()'],['../classwx_affine_matrix2_d_base.html#ab6c40a633a3bd3ad7919aaf5080b94d7',1,'wxAffineMatrix2DBase::Mirror()'],['../classwx_image.html#abe3a18acec23fc0afbae68c5ec3f446f',1,'wxImage::Mirror()']]],
  ['mkdir',['MkDir',['../classwx_f_t_p.html#ac9d150320640a50b8644fc56a9cbef91',1,'wxFTP::MkDir()'],['../classwx_file_name.html#a852d4f699225e767242d54df53d6f3be',1,'wxFileName::Mkdir(int perm=wxS_DIR_DEFAULT, int flags=0) const '],['../classwx_file_name.html#ac2006b2fb30c0c0f11ef44560e1a62c7',1,'wxFileName::Mkdir(const wxString &amp;dir, int perm=wxS_DIR_DEFAULT, int flags=0)']]],
  ['modify',['Modify',['../classwx_document.html#a5a4fedba3df42a4b133bf16ba3a8ef1d',1,'wxDocument::Modify()'],['../classwx_rich_text_buffer.html#aab98da3dc48d1f615721e60605c18096',1,'wxRichTextBuffer::Modify()']]],
  ['month',['Month',['../classwx_date_span.html#a14e488e59083c754acfd96adf5a291d9',1,'wxDateSpan']]],
  ['months',['Months',['../classwx_date_span.html#af2ec625e1a50d3eaae04b7df46bdacba',1,'wxDateSpan']]],
  ['morerequested',['MoreRequested',['../classwx_idle_event.html#a914b7316db91fb71d21c899048666eca',1,'wxIdleEvent']]],
  ['mouseclick',['MouseClick',['../classwx_u_i_action_simulator.html#a9b1c032466a935687c5e68d6eb77bcc5',1,'wxUIActionSimulator']]],
  ['mouseclickbegin',['MouseClickBegin',['../classwx_mouse_events_manager.html#a543da21dccf90eb88a67d9b2175dbd9b',1,'wxMouseEventsManager']]],
  ['mouseclickcancelled',['MouseClickCancelled',['../classwx_mouse_events_manager.html#a9fd1d3883b222936d0704dd18ca8f599',1,'wxMouseEventsManager']]],
  ['mouseclicked',['MouseClicked',['../classwx_mouse_events_manager.html#aef800a0d0d71c2ccdc1b797e52a0f282',1,'wxMouseEventsManager']]],
  ['mousedblclick',['MouseDblClick',['../classwx_u_i_action_simulator.html#aee0c2122c457fbd25bebb37e1f87e436',1,'wxUIActionSimulator']]],
  ['mousedown',['MouseDown',['../classwx_u_i_action_simulator.html#a9ddaf261490d1a71f723e713184424a1',1,'wxUIActionSimulator']]],
  ['mousedragbegin',['MouseDragBegin',['../classwx_mouse_events_manager.html#a6efa90616c6fa3b01bcd9a2e7b7c3d12',1,'wxMouseEventsManager']]],
  ['mousedragcancelled',['MouseDragCancelled',['../classwx_mouse_events_manager.html#aab7d86df3e6b9a61facb5199f9f6b631',1,'wxMouseEventsManager']]],
  ['mousedragdrop',['MouseDragDrop',['../classwx_u_i_action_simulator.html#a9365e46a8500daac15eadbbdc7c6fb9d',1,'wxUIActionSimulator']]],
  ['mousedragend',['MouseDragEnd',['../classwx_mouse_events_manager.html#a202263161d841caeb9d5c47a8c87db16',1,'wxMouseEventsManager']]],
  ['mousedragging',['MouseDragging',['../classwx_mouse_events_manager.html#a06919af9b1d82f0ba33046620e82d3f0',1,'wxMouseEventsManager']]],
  ['mousehittest',['MouseHitTest',['../classwx_mouse_events_manager.html#ac0b0ee5a5987470f523a03630ba4b6e4',1,'wxMouseEventsManager']]],
  ['mousemove',['MouseMove',['../classwx_u_i_action_simulator.html#a810d21924e14cb66205e4a921f711e5a',1,'wxUIActionSimulator::MouseMove(long x, long y)'],['../classwx_u_i_action_simulator.html#aca7da1cd2fe227f2b1a85cfe8aef828b',1,'wxUIActionSimulator::MouseMove(const wxPoint &amp;point)']]],
  ['mouseup',['MouseUp',['../classwx_u_i_action_simulator.html#a84bb2f01cfc044d682cbadd9efb9846f',1,'wxUIActionSimulator']]],
  ['movable',['Movable',['../classwx_aui_pane_info.html#a588a92bdf72411a6d72265c54a6ddd2d',1,'wxAuiPaneInfo']]],
  ['move',['Move',['../classwx_caret.html#ae490dc3156c4c686bc37f601edc33388',1,'wxCaret::Move(int x, int y)'],['../classwx_caret.html#a4b1e2c18b950f771b44172b752d6eb1b',1,'wxCaret::Move(const wxPoint &amp;pt)'],['../classwx_drag_image.html#a51b7a0377bbdd79ad8d93c7bb1a67644',1,'wxDragImage::Move()'],['../classwx_rich_text_object.html#a120eeb05778458428e92c3528ccfba03',1,'wxRichTextObject::Move()'],['../classwx_rich_text_composite_object.html#a972cfc5642595f484850c0d3e75c92ff',1,'wxRichTextCompositeObject::Move()'],['../classwx_window.html#ab1cb98c8d25b9e6ff7b706b1446c3df7',1,'wxWindow::Move(int x, int y, int flags=wxSIZE_USE_EXISTING)'],['../classwx_window.html#a22a22c1e23ca05776707e7999d8047fe',1,'wxWindow::Move(const wxPoint &amp;pt, int flags=wxSIZE_USE_EXISTING)']]],
  ['moveafterintaborder',['MoveAfterInTabOrder',['../classwx_window.html#a79e66079125e8420de269811bdb6f2b6',1,'wxWindow']]],
  ['moveanchoredobjecttoparagraph',['MoveAnchoredObjectToParagraph',['../classwx_rich_text_paragraph_layout_box.html#af0b0f2cb12a0a03979b67cfbc2f28e9a',1,'wxRichTextParagraphLayoutBox']]],
  ['movebeforeintaborder',['MoveBeforeInTabOrder',['../classwx_window.html#af2b92f61cd9f9e2e0efe4cce307e25b1',1,'wxWindow']]],
  ['movebottomto',['MoveBottomTo',['../classwx_rect2_d_double.html#a26499878fc89bf68c8e2c079eeae7605',1,'wxRect2DDouble::MoveBottomTo()'],['../classwx_rect2_d_int.html#ab10e2f2e33bedd1d9cb45957d90d93dd',1,'wxRect2DInt::MoveBottomTo()']]],
  ['movecaret',['MoveCaret',['../classwx_rich_text_ctrl.html#a56e377157113a0c495a5f2e8eb5fdeac',1,'wxRichTextCtrl']]],
  ['movecaretback',['MoveCaretBack',['../classwx_rich_text_ctrl.html#aa09acf155ea4a2be4246b51bcd15351e',1,'wxRichTextCtrl']]],
  ['movecaretforward',['MoveCaretForward',['../classwx_rich_text_ctrl.html#a4edb35a8793d371c8bb7be4db28c3cba',1,'wxRichTextCtrl']]],
  ['movecaretinsideview',['MoveCaretInsideView',['../classwx_styled_text_ctrl.html#a88b9b807e250da28f23f26bf4dba09ff',1,'wxStyledTextCtrl']]],
  ['movecentreto',['MoveCentreTo',['../classwx_rect2_d_double.html#a05da8c5e1902bddad6c409a2f2857cc6',1,'wxRect2DDouble::MoveCentreTo()'],['../classwx_rect2_d_int.html#a5bc591af720c88e9a16349ce496a4d96',1,'wxRect2DInt::MoveCentreTo()']]],
  ['movecolumninorderarray',['MoveColumnInOrderArray',['../classwx_header_ctrl.html#a8046ddebbcdf8a6d82f1da144cf868ea',1,'wxHeaderCtrl']]],
  ['movecurrentdown',['MoveCurrentDown',['../classwx_rearrange_list.html#a71a00acdbae45613486d562b7bc17470',1,'wxRearrangeList']]],
  ['movecurrentup',['MoveCurrentUp',['../classwx_rearrange_list.html#a03703035ef32e9d1596138f3a8595070',1,'wxRearrangeList']]],
  ['movecursordown',['MoveCursorDown',['../classwx_grid.html#a366e838f760491f500a1ee92aacd47f6',1,'wxGrid']]],
  ['movecursordownblock',['MoveCursorDownBlock',['../classwx_grid.html#a91ae663fda79c0c71001799940f073bc',1,'wxGrid']]],
  ['movecursorleft',['MoveCursorLeft',['../classwx_grid.html#ae40bbcd9a916013622102ea1a05e2054',1,'wxGrid']]],
  ['movecursorleftblock',['MoveCursorLeftBlock',['../classwx_grid.html#a592dbda3f66ce2450b6d1ca54ccc1f15',1,'wxGrid']]],
  ['movecursorright',['MoveCursorRight',['../classwx_grid.html#a94ac571c0e0ea6feca2f10e06e23335d',1,'wxGrid']]],
  ['movecursorrightblock',['MoveCursorRightBlock',['../classwx_grid.html#a0ccd8de3b784ca7fa93480eff9e5235d',1,'wxGrid']]],
  ['movecursorup',['MoveCursorUp',['../classwx_grid.html#aa6fb5bd1011cf2915a59cdd807e2b1fa',1,'wxGrid']]],
  ['movecursorupblock',['MoveCursorUpBlock',['../classwx_grid.html#a2ffacf3f71e073b9e66c15baba4d520a',1,'wxGrid']]],
  ['movedown',['MoveDown',['../classwx_rich_text_ctrl.html#a6fd3e1bd2158d50a3da6e808feb0e79a',1,'wxRichTextCtrl']]],
  ['moveend',['MoveEnd',['../classwx_rich_text_ctrl.html#a919488276746ebda684fa15cceba7eca',1,'wxRichTextCtrl']]],
  ['movefromlist',['MoveFromList',['../classwx_rich_text_paragraph.html#a058d90eb75476eecf868574ff74064eb',1,'wxRichTextParagraph']]],
  ['movehome',['MoveHome',['../classwx_rich_text_ctrl.html#af35a7351560e2cc35bae6f25d20ff5bc',1,'wxRichTextCtrl']]],
  ['moveleft',['MoveLeft',['../classwx_rich_text_ctrl.html#a545b9871544b9d191af3b21ae07abe6a',1,'wxRichTextCtrl']]],
  ['moveleftbottomto',['MoveLeftBottomTo',['../classwx_rect2_d_double.html#ab6434d2194833ec85c8f847883ea0335',1,'wxRect2DDouble::MoveLeftBottomTo()'],['../classwx_rect2_d_int.html#a1bfa75c18c076f4a4232eb46844eb169',1,'wxRect2DInt::MoveLeftBottomTo()']]],
  ['moveleftto',['MoveLeftTo',['../classwx_rect2_d_double.html#a535ab2cdb4a7f10f8018afd25b542a4d',1,'wxRect2DDouble::MoveLeftTo()'],['../classwx_rect2_d_int.html#a1af47077024640955f55dcdcb0b28eb1',1,'wxRect2DInt::MoveLeftTo()']]],
  ['movelefttopto',['MoveLeftTopTo',['../classwx_rect2_d_double.html#abc56d7e1e725ea01eee921748eb7abf7',1,'wxRect2DDouble::MoveLeftTopTo()'],['../classwx_rect2_d_int.html#a6b6d0e6043db597cb2dcfa72d6a46d5b',1,'wxRect2DInt::MoveLeftTopTo()']]],
  ['movepage',['MovePage',['../classwx_aui_tab_container.html#a198bf662b4d18f6fda5a6f68b9659640',1,'wxAuiTabContainer']]],
  ['movepagedown',['MovePageDown',['../classwx_grid.html#ae28d8cc8ab2cbf9e6edf3ddddeb7b9cd',1,'wxGrid']]],
  ['movepageup',['MovePageUp',['../classwx_grid.html#a11c6c8e07f62e18a97cff5ef2d2375bb',1,'wxGrid']]],
  ['moveright',['MoveRight',['../classwx_rich_text_ctrl.html#a4e1fd7f8705d971bdb54a9b03ac0d165',1,'wxRichTextCtrl']]],
  ['moverightbottomto',['MoveRightBottomTo',['../classwx_rect2_d_double.html#a7d099240cc477eef19902171d25e76ca',1,'wxRect2DDouble::MoveRightBottomTo()'],['../classwx_rect2_d_int.html#a62f56cc0bb801ba0527023586e8439fa',1,'wxRect2DInt::MoveRightBottomTo()']]],
  ['moverightto',['MoveRightTo',['../classwx_rect2_d_double.html#a42f416964661dccb3346187765b7d9ac',1,'wxRect2DDouble::MoveRightTo()'],['../classwx_rect2_d_int.html#a81193a8a68eda09d50971a89c0e5d45f',1,'wxRect2DInt::MoveRightTo()']]],
  ['moverighttopto',['MoveRightTopTo',['../classwx_rect2_d_double.html#aafefcd25d4d98795d4fceb448c2cdad1',1,'wxRect2DDouble::MoveRightTopTo()'],['../classwx_rect2_d_int.html#af947d383e89608750e4abad381e347bf',1,'wxRect2DInt::MoveRightTopTo()']]],
  ['moveselectedlinesdown',['MoveSelectedLinesDown',['../classwx_styled_text_ctrl.html#a167ff7a45de7fe4f5a4ed8080ad278ae',1,'wxStyledTextCtrl']]],
  ['moveselectedlinesup',['MoveSelectedLinesUp',['../classwx_styled_text_ctrl.html#a505aaf57dfde28f24de8c01e8b5ea786',1,'wxStyledTextCtrl']]],
  ['moveto',['MoveTo',['../classwx_pixel_data_1_1_iterator.html#a8fc62aab73405b74c0d7afd5081c74c4',1,'wxPixelData::Iterator']]],
  ['movetolineend',['MoveToLineEnd',['../classwx_rich_text_ctrl.html#aca2d9e5d1437b4de708384e0b609b08a',1,'wxRichTextCtrl']]],
  ['movetolinestart',['MoveToLineStart',['../classwx_rich_text_ctrl.html#a1ed4408bca2d282aee27e7fb425459c7',1,'wxRichTextCtrl']]],
  ['movetolist',['MoveToList',['../classwx_rich_text_paragraph.html#a06f3e91375e7d8563cd4cb88b6f91109',1,'wxRichTextParagraph']]],
  ['movetoparagraphend',['MoveToParagraphEnd',['../classwx_rich_text_ctrl.html#a20edf3ac4d91b825aca03439de817256',1,'wxRichTextCtrl']]],
  ['movetoparagraphstart',['MoveToParagraphStart',['../classwx_rich_text_ctrl.html#a7aa28b8b36aa9cf8a1a1dec4af71b8c6',1,'wxRichTextCtrl']]],
  ['movetopoint',['MoveToPoint',['../classwx_graphics_path.html#a62c899479b6bd2105507317a1246978e',1,'wxGraphicsPath::MoveToPoint(wxDouble x, wxDouble y)'],['../classwx_graphics_path.html#a42a800a76412ad4ae2eb276ba4016f37',1,'wxGraphicsPath::MoveToPoint(const wxPoint2DDouble &amp;p)']]],
  ['movetopto',['MoveTopTo',['../classwx_rect2_d_double.html#a03029c3211c844fc0764196bfd27bd15',1,'wxRect2DDouble::MoveTopTo()'],['../classwx_rect2_d_int.html#a0b353fdf7166552b836eb530526feaba',1,'wxRect2DInt::MoveTopTo()']]],
  ['moveup',['MoveUp',['../classwx_rich_text_ctrl.html#abe6115be0c8bbf5a3d740e17ea2f09c7',1,'wxRichTextCtrl']]],
  ['moving',['Moving',['../classwx_mouse_event.html#a4ba54065ea560c30d59fc38cec077c1f',1,'wxMouseEvent']]],
  ['mswgethandle',['MSWGetHandle',['../classwx_thread.html#a557af76b380550f08bbcf4a6ec12b2ab',1,'wxThread']]],
  ['mswgetshelldir',['MSWGetShellDir',['../classwx_standard_paths.html#a5a523db5b6aca46154ac76d264d2bb57',1,'wxStandardPaths']]],
  ['mswgetsystemmenu',['MSWGetSystemMenu',['../classwx_top_level_window.html#a503565e9c0a1f37a281b52e1d53029b6',1,'wxTopLevelWindow']]],
  ['mswgettaskbarbutton',['MSWGetTaskBarButton',['../classwx_frame.html#a854554645446695649922860a9c94ea7',1,'wxFrame']]],
  ['mswusetoasts',['MSWUseToasts',['../classwx_notification_message.html#a52c56483b083d771de4d0819f4795242',1,'wxNotificationMessage']]],
  ['multiply',['Multiply',['../classwx_date_span.html#a1008611f2389be37786d76d816ffbda1',1,'wxDateSpan::Multiply(int factor) const '],['../classwx_date_span.html#a575ba275ad24b6230b25daa451494ada',1,'wxDateSpan::Multiply(int factor)'],['../classwx_time_span.html#ab515cf02a32b07825ca99a6a99327a5f',1,'wxTimeSpan::Multiply(int n) const '],['../classwx_time_span.html#a3ca6fdcf682d05c27c4be20143404253',1,'wxTimeSpan::Multiply(int n)']]]
];
